.\" file MASS/corresp.d
.\" copyright (C) 1994-9 W. N. Venables and B. D. Ripley
.\"
.BG
.FN corresp
.TL
Simple Correspondence Analysis
.DN
Find the principal canonical correlation and corresponding row- and
column-scores from a correspondence analysis of a two-way contingency
table.
.CS
corresp(x, nf=1, ...)
.RA
.AG x
The function is generic, accepting various forms of the principal
argument for specifying a two-way frequency table.  Currently accepted
forms are matrices, data frames (coerced to frequency tables), objects
of class `"crosstabs"' and formulae of the form `~ F1 + F2', where `F1'
and `F2' are factors.
.OA
.AG nf
The number of factors to be computed. Note that although 1 is the most
usual, one school of thought takes the first two singular vectors for
a sort of biplot.
.AG ...
If the principal argument is a formula, a data frame may be specified
as well from which variables in the formula are preferentially
satisfied.
.RT
An list object of class `"correspondence"' for which `print', `plot' and
`biplot' methods are supplied.  The main components are the canonical
correlation(s) and the row and column scores. 
.DT
See the reference.  The `plot' method produces a graphical
representation of the table if `nf=1', with the \fIareas\fP of circles
representing the numbers of points.  If `nf' is two or more the
`biplot' method is called, which plots the second and third columns of
the matrices `A = Dr^(-1/2) U L' and `B = Dc^(-1/2) U V' where the
singular value decomposition is `U L V'.  Thus the x-axis is the
canonical correlation times the row and column scores. Although this
is called a biplot, it does \fInot\fP have any useful inner product
relationship between the row and column scores.  Think of this as an
equally-scaled plot with two unrelated sets of labels.
.SH REFERENCE
Venables & Ripley (1999), chapter 11.
.SA
`svd', `princomp'
.EX
ct <- corresp(~ Age + Eth, data=quine)
ct
plot(ct)

corresp(caith)
biplot(corresp(caith, nf=2))
.KW category
.KW multivariate
.WR
